# This file is @generated by `scripts/codegen.py imports`. Do not edit.

from typing import TYPE_CHECKING

from githubkit.versions.latest.models import (
    WebhookPullRequestReviewRequestedOneof0,
    WebhookPullRequestReviewRequestedOneof1,
    WebhookPullRequestReviewRequestRemovedOneof0,
    WebhookPullRequestReviewRequestRemovedOneof1,
)

PullRequestReviewRequested = (
    WebhookPullRequestReviewRequestedOneof0 | WebhookPullRequestReviewRequestedOneof1
)
PullRequestReviewRequestRemoved = (
    WebhookPullRequestReviewRequestRemovedOneof0
    | WebhookPullRequestReviewRequestRemovedOneof1
)

if TYPE_CHECKING:
    from githubkit.versions.latest.webhooks import (  # noqa: I001
        BranchProtectionConfigurationEvent as BranchProtectionConfiguration,
        BranchProtectionRuleEvent as BranchProtectionRule,
        CheckRunEvent as CheckRun,
        CheckSuiteEvent as CheckSuite,
        CodeScanningAlertEvent as CodeScanningAlert,
        CommitCommentEvent as CommitComment,
        CreateEvent as Create,
        CustomPropertyEvent as CustomProperty,
        CustomPropertyValuesEvent as CustomPropertyValues,
        DeleteEvent as Delete,
        DependabotAlertEvent as DependabotAlert,
        DeployKeyEvent as DeployKey,
        DeploymentEvent as Deployment,
        DeploymentProtectionRuleEvent as DeploymentProtectionRule,
        DeploymentReviewEvent as DeploymentReview,
        DeploymentStatusEvent as DeploymentStatus,
        DiscussionCommentEvent as DiscussionComment,
        DiscussionEvent as Discussion,
        ForkEvent as Fork,
        GithubAppAuthorizationEvent as GithubAppAuthorization,
        GollumEvent as Gollum,
        InstallationEvent as Installation,
        InstallationRepositoriesEvent as InstallationRepositories,
        InstallationTargetEvent as InstallationTarget,
        IssueCommentEvent as IssueComment,
        IssueDependenciesEvent as IssueDependencies,
        IssuesEvent as Issues,
        LabelEvent as Label,
        MarketplacePurchaseEvent as MarketplacePurchase,
        MemberEvent as Member,
        MembershipEvent as Membership,
        MergeGroupEvent as MergeGroup,
        MetaEvent as Meta,
        MilestoneEvent as Milestone,
        OrgBlockEvent as OrgBlock,
        OrganizationEvent as Organization,
        PackageEvent as Package,
        PageBuildEvent as PageBuild,
        PersonalAccessTokenRequestEvent as PersonalAccessTokenRequest,
        PingEvent as Ping,
        ProjectCardEvent as ProjectCard,
        ProjectColumnEvent as ProjectColumn,
        ProjectEvent as Project,
        ProjectsV2Event as ProjectsV2,
        ProjectsV2ItemEvent as ProjectsV2Item,
        ProjectsV2StatusUpdateEvent as ProjectsV2StatusUpdate,
        PublicEvent as Public,
        PullRequestEvent as PullRequest,
        PullRequestReviewCommentEvent as PullRequestReviewComment,
        PullRequestReviewEvent as PullRequestReview,
        PullRequestReviewThreadEvent as PullRequestReviewThread,
        PushEvent as Push,
        RegistryPackageEvent as RegistryPackage,
        ReleaseEvent as Release,
        RepositoryAdvisoryEvent as RepositoryAdvisory,
        RepositoryDispatchEvent as RepositoryDispatch,
        RepositoryEvent as Repository,
        RepositoryImportEvent as RepositoryImport,
        RepositoryRulesetEvent as RepositoryRuleset,
        RepositoryVulnerabilityAlertEvent as RepositoryVulnerabilityAlert,
        SecretScanningAlertEvent as SecretScanningAlert,
        SecretScanningAlertLocationEvent as SecretScanningAlertLocation,
        SecretScanningScanEvent as SecretScanningScan,
        SecurityAdvisoryEvent as SecurityAdvisory,
        SecurityAndAnalysisEvent as SecurityAndAnalysis,
        SponsorshipEvent as Sponsorship,
        StarEvent as Star,
        StatusEvent as Status,
        SubIssuesEvent as SubIssues,
        TeamAddEvent as TeamAdd,
        TeamEvent as Team,
        WatchEvent as Watch,
        WebhookEvent as Any,
        WorkflowDispatchEvent as WorkflowDispatch,
        WorkflowJobEvent as WorkflowJob,
        WorkflowRunEvent as WorkflowRun,
    )
    from githubkit.versions.latest.models import (
        WebhookBranchProtectionConfigurationDisabled as BranchProtectionConfigurationDisabled,
        WebhookBranchProtectionConfigurationEnabled as BranchProtectionConfigurationEnabled,
        WebhookBranchProtectionRuleCreated as BranchProtectionRuleCreated,
        WebhookBranchProtectionRuleDeleted as BranchProtectionRuleDeleted,
        WebhookBranchProtectionRuleEdited as BranchProtectionRuleEdited,
        WebhookCheckRunCompleted as CheckRunCompleted,
        WebhookCheckRunCreated as CheckRunCreated,
        WebhookCheckRunRequestedAction as CheckRunRequestedAction,
        WebhookCheckRunRerequested as CheckRunRerequested,
        WebhookCheckSuiteCompleted as CheckSuiteCompleted,
        WebhookCheckSuiteRequested as CheckSuiteRequested,
        WebhookCheckSuiteRerequested as CheckSuiteRerequested,
        WebhookCodeScanningAlertAppearedInBranch as CodeScanningAlertAppearedInBranch,
        WebhookCodeScanningAlertClosedByUser as CodeScanningAlertClosedByUser,
        WebhookCodeScanningAlertCreated as CodeScanningAlertCreated,
        WebhookCodeScanningAlertFixed as CodeScanningAlertFixed,
        WebhookCodeScanningAlertReopened as CodeScanningAlertReopened,
        WebhookCodeScanningAlertReopenedByUser as CodeScanningAlertReopenedByUser,
        WebhookCodeScanningAlertUpdatedAssignment as CodeScanningAlertUpdatedAssignment,
        WebhookCommitCommentCreated as CommitCommentCreated,
        WebhookCustomPropertyCreated as CustomPropertyCreated,
        WebhookCustomPropertyDeleted as CustomPropertyDeleted,
        WebhookCustomPropertyPromotedToEnterprise as CustomPropertyPromoteToEnterprise,
        WebhookCustomPropertyUpdated as CustomPropertyUpdated,
        WebhookCustomPropertyValuesUpdated as CustomPropertyValuesUpdated,
        WebhookDependabotAlertAssigneesChanged as DependabotAlertAssigneesChanged,
        WebhookDependabotAlertAutoDismissed as DependabotAlertAutoDismissed,
        WebhookDependabotAlertAutoReopened as DependabotAlertAutoReopened,
        WebhookDependabotAlertCreated as DependabotAlertCreated,
        WebhookDependabotAlertDismissed as DependabotAlertDismissed,
        WebhookDependabotAlertFixed as DependabotAlertFixed,
        WebhookDependabotAlertReintroduced as DependabotAlertReintroduced,
        WebhookDependabotAlertReopened as DependabotAlertReopened,
        WebhookDeployKeyCreated as DeployKeyCreated,
        WebhookDeployKeyDeleted as DeployKeyDeleted,
        WebhookDeploymentCreated as DeploymentCreated,
        WebhookDeploymentProtectionRuleRequested as DeploymentProtectionRuleRequested,
        WebhookDeploymentReviewApproved as DeploymentReviewApproved,
        WebhookDeploymentReviewRejected as DeploymentReviewRejected,
        WebhookDeploymentReviewRequested as DeploymentReviewRequested,
        WebhookDeploymentStatusCreated as DeploymentStatusCreated,
        WebhookDiscussionAnswered as DiscussionAnswered,
        WebhookDiscussionCategoryChanged as DiscussionCategoryChanged,
        WebhookDiscussionClosed as DiscussionClosed,
        WebhookDiscussionCommentCreated as DiscussionCommentCreated,
        WebhookDiscussionCommentDeleted as DiscussionCommentDeleted,
        WebhookDiscussionCommentEdited as DiscussionCommentEdited,
        WebhookDiscussionCreated as DiscussionCreated,
        WebhookDiscussionDeleted as DiscussionDeleted,
        WebhookDiscussionEdited as DiscussionEdited,
        WebhookDiscussionLabeled as DiscussionLabeled,
        WebhookDiscussionLocked as DiscussionLocked,
        WebhookDiscussionPinned as DiscussionPinned,
        WebhookDiscussionReopened as DiscussionReopened,
        WebhookDiscussionTransferred as DiscussionTransferred,
        WebhookDiscussionUnanswered as DiscussionUnanswered,
        WebhookDiscussionUnlabeled as DiscussionUnlabeled,
        WebhookDiscussionUnlocked as DiscussionUnlocked,
        WebhookDiscussionUnpinned as DiscussionUnpinned,
        WebhookGithubAppAuthorizationRevoked as GithubAppAuthorizationRevoked,
        WebhookInstallationCreated as InstallationCreated,
        WebhookInstallationDeleted as InstallationDeleted,
        WebhookInstallationNewPermissionsAccepted as InstallationNewPermissionsAccepted,
        WebhookInstallationRepositoriesAdded as InstallationRepositoriesAdded,
        WebhookInstallationRepositoriesRemoved as InstallationRepositoriesRemoved,
        WebhookInstallationSuspend as InstallationSuspend,
        WebhookInstallationTargetRenamed as InstallationTargetRenamed,
        WebhookInstallationUnsuspend as InstallationUnsuspend,
        WebhookIssueCommentCreated as IssueCommentCreated,
        WebhookIssueCommentDeleted as IssueCommentDeleted,
        WebhookIssueCommentEdited as IssueCommentEdited,
        WebhookIssueCommentPinned as IssueCommentPinned,
        WebhookIssueCommentUnpinned as IssueCommentUnpinned,
        WebhookIssueDependenciesBlockedByAdded as IssueDependenciesBlockedByAdded,
        WebhookIssueDependenciesBlockedByRemoved as IssueDependenciesBlockedByRemoved,
        WebhookIssueDependenciesBlockingAdded as IssueDependenciesBlockingAdded,
        WebhookIssueDependenciesBlockingRemoved as IssueDependenciesBlockingRemoved,
        WebhookIssuesAssigned as IssuesAssigned,
        WebhookIssuesClosed as IssuesClosed,
        WebhookIssuesDeleted as IssuesDeleted,
        WebhookIssuesDemilestoned as IssuesDemilestoned,
        WebhookIssuesEdited as IssuesEdited,
        WebhookIssuesLabeled as IssuesLabeled,
        WebhookIssuesLocked as IssuesLocked,
        WebhookIssuesMilestoned as IssuesMilestoned,
        WebhookIssuesOpened as IssuesOpened,
        WebhookIssuesPinned as IssuesPinned,
        WebhookIssuesReopened as IssuesReopened,
        WebhookIssuesTransferred as IssuesTransferred,
        WebhookIssuesTyped as IssuesTyped,
        WebhookIssuesUnassigned as IssuesUnassigned,
        WebhookIssuesUnlabeled as IssuesUnlabeled,
        WebhookIssuesUnlocked as IssuesUnlocked,
        WebhookIssuesUnpinned as IssuesUnpinned,
        WebhookIssuesUntyped as IssuesUntyped,
        WebhookLabelCreated as LabelCreated,
        WebhookLabelDeleted as LabelDeleted,
        WebhookLabelEdited as LabelEdited,
        WebhookMarketplacePurchaseCancelled as MarketplacePurchaseCancelled,
        WebhookMarketplacePurchaseChanged as MarketplacePurchaseChanged,
        WebhookMarketplacePurchasePendingChange as MarketplacePurchasePendingChange,
        WebhookMarketplacePurchasePendingChangeCancelled as MarketplacePurchasePendingChangeCancelled,
        WebhookMarketplacePurchasePurchased as MarketplacePurchasePurchased,
        WebhookMemberAdded as MemberAdded,
        WebhookMemberEdited as MemberEdited,
        WebhookMemberRemoved as MemberRemoved,
        WebhookMembershipAdded as MembershipAdded,
        WebhookMembershipRemoved as MembershipRemoved,
        WebhookMergeGroupChecksRequested as MergeGroupChecksRequested,
        WebhookMergeGroupDestroyed as MergeGroupDestroyed,
        WebhookMetaDeleted as MetaDeleted,
        WebhookMilestoneClosed as MilestoneClosed,
        WebhookMilestoneCreated as MilestoneCreated,
        WebhookMilestoneDeleted as MilestoneDeleted,
        WebhookMilestoneEdited as MilestoneEdited,
        WebhookMilestoneOpened as MilestoneOpened,
        WebhookOrgBlockBlocked as OrgBlockBlocked,
        WebhookOrgBlockUnblocked as OrgBlockUnblocked,
        WebhookOrganizationDeleted as OrganizationDeleted,
        WebhookOrganizationMemberAdded as OrganizationMemberAdded,
        WebhookOrganizationMemberInvited as OrganizationMemberInvited,
        WebhookOrganizationMemberRemoved as OrganizationMemberRemoved,
        WebhookOrganizationRenamed as OrganizationRenamed,
        WebhookPackagePublished as PackagePublished,
        WebhookPackageUpdated as PackageUpdated,
        WebhookPersonalAccessTokenRequestApproved as PersonalAccessTokenRequestApproved,
        WebhookPersonalAccessTokenRequestCancelled as PersonalAccessTokenRequestCancelled,
        WebhookPersonalAccessTokenRequestCreated as PersonalAccessTokenRequestCreated,
        WebhookPersonalAccessTokenRequestDenied as PersonalAccessTokenRequestDenied,
        WebhookProjectCardConverted as ProjectCardConverted,
        WebhookProjectCardCreated as ProjectCardCreated,
        WebhookProjectCardDeleted as ProjectCardDeleted,
        WebhookProjectCardEdited as ProjectCardEdited,
        WebhookProjectCardMoved as ProjectCardMoved,
        WebhookProjectClosed as ProjectClosed,
        WebhookProjectColumnCreated as ProjectColumnCreated,
        WebhookProjectColumnDeleted as ProjectColumnDeleted,
        WebhookProjectColumnEdited as ProjectColumnEdited,
        WebhookProjectColumnMoved as ProjectColumnMoved,
        WebhookProjectCreated as ProjectCreated,
        WebhookProjectDeleted as ProjectDeleted,
        WebhookProjectEdited as ProjectEdited,
        WebhookProjectReopened as ProjectReopened,
        WebhookProjectsV2ItemArchived as ProjectsV2ItemArchived,
        WebhookProjectsV2ItemConverted as ProjectsV2ItemConverted,
        WebhookProjectsV2ItemCreated as ProjectsV2ItemCreated,
        WebhookProjectsV2ItemDeleted as ProjectsV2ItemDeleted,
        WebhookProjectsV2ItemEdited as ProjectsV2ItemEdited,
        WebhookProjectsV2ItemReordered as ProjectsV2ItemReordered,
        WebhookProjectsV2ItemRestored as ProjectsV2ItemRestored,
        WebhookProjectsV2ProjectClosed as ProjectsV2ProjectClosed,
        WebhookProjectsV2ProjectCreated as ProjectsV2ProjectCreated,
        WebhookProjectsV2ProjectDeleted as ProjectsV2ProjectDeleted,
        WebhookProjectsV2ProjectEdited as ProjectsV2ProjectEdited,
        WebhookProjectsV2ProjectReopened as ProjectsV2ProjectReopened,
        WebhookProjectsV2StatusUpdateCreated as ProjectsV2StatusUpdateCreated,
        WebhookProjectsV2StatusUpdateDeleted as ProjectsV2StatusUpdateDeleted,
        WebhookProjectsV2StatusUpdateEdited as ProjectsV2StatusUpdateEdited,
        WebhookPullRequestAssigned as PullRequestAssigned,
        WebhookPullRequestAutoMergeDisabled as PullRequestAutoMergeDisabled,
        WebhookPullRequestAutoMergeEnabled as PullRequestAutoMergeEnabled,
        WebhookPullRequestClosed as PullRequestClosed,
        WebhookPullRequestConvertedToDraft as PullRequestConvertedToDraft,
        WebhookPullRequestDemilestoned as PullRequestDemilestoned,
        WebhookPullRequestDequeued as PullRequestDequeued,
        WebhookPullRequestEdited as PullRequestEdited,
        WebhookPullRequestEnqueued as PullRequestEnqueued,
        WebhookPullRequestLabeled as PullRequestLabeled,
        WebhookPullRequestLocked as PullRequestLocked,
        WebhookPullRequestMilestoned as PullRequestMilestoned,
        WebhookPullRequestOpened as PullRequestOpened,
        WebhookPullRequestReadyForReview as PullRequestReadyForReview,
        WebhookPullRequestReopened as PullRequestReopened,
        WebhookPullRequestReviewCommentCreated as PullRequestReviewCommentCreated,
        WebhookPullRequestReviewCommentDeleted as PullRequestReviewCommentDeleted,
        WebhookPullRequestReviewCommentEdited as PullRequestReviewCommentEdited,
        WebhookPullRequestReviewDismissed as PullRequestReviewDismissed,
        WebhookPullRequestReviewEdited as PullRequestReviewEdited,
        WebhookPullRequestReviewSubmitted as PullRequestReviewSubmitted,
        WebhookPullRequestReviewThreadResolved as PullRequestReviewThreadResolved,
        WebhookPullRequestReviewThreadUnresolved as PullRequestReviewThreadUnresolved,
        WebhookPullRequestSynchronize as PullRequestSynchronize,
        WebhookPullRequestUnassigned as PullRequestUnassigned,
        WebhookPullRequestUnlabeled as PullRequestUnlabeled,
        WebhookPullRequestUnlocked as PullRequestUnlocked,
        WebhookRegistryPackagePublished as RegistryPackagePublished,
        WebhookRegistryPackageUpdated as RegistryPackageUpdated,
        WebhookReleaseCreated as ReleaseCreated,
        WebhookReleaseDeleted as ReleaseDeleted,
        WebhookReleaseEdited as ReleaseEdited,
        WebhookReleasePrereleased as ReleasePrereleased,
        WebhookReleasePublished as ReleasePublished,
        WebhookReleaseReleased as ReleaseReleased,
        WebhookReleaseUnpublished as ReleaseUnpublished,
        WebhookRepositoryAdvisoryPublished as RepositoryAdvisoryPublished,
        WebhookRepositoryAdvisoryReported as RepositoryAdvisoryReported,
        WebhookRepositoryArchived as RepositoryArchived,
        WebhookRepositoryCreated as RepositoryCreated,
        WebhookRepositoryDeleted as RepositoryDeleted,
        WebhookRepositoryDispatchSample as RepositoryDispatchSample,
        WebhookRepositoryEdited as RepositoryEdited,
        WebhookRepositoryPrivatized as RepositoryPrivatized,
        WebhookRepositoryPublicized as RepositoryPublicized,
        WebhookRepositoryRenamed as RepositoryRenamed,
        WebhookRepositoryRulesetCreated as RepositoryRulesetCreated,
        WebhookRepositoryRulesetDeleted as RepositoryRulesetDeleted,
        WebhookRepositoryRulesetEdited as RepositoryRulesetEdited,
        WebhookRepositoryTransferred as RepositoryTransferred,
        WebhookRepositoryUnarchived as RepositoryUnarchived,
        WebhookRepositoryVulnerabilityAlertCreate as RepositoryVulnerabilityAlertCreate,
        WebhookRepositoryVulnerabilityAlertDismiss as RepositoryVulnerabilityAlertDismiss,
        WebhookRepositoryVulnerabilityAlertReopen as RepositoryVulnerabilityAlertReopen,
        WebhookRepositoryVulnerabilityAlertResolve as RepositoryVulnerabilityAlertResolve,
        WebhookSecretScanningAlertAssigned as SecretScanningAlertAssigned,
        WebhookSecretScanningAlertCreated as SecretScanningAlertCreated,
        WebhookSecretScanningAlertLocationCreated as SecretScanningAlertLocationCreated,
        WebhookSecretScanningAlertPubliclyLeaked as SecretScanningAlertPubliclyLeaked,
        WebhookSecretScanningAlertReopened as SecretScanningAlertReopened,
        WebhookSecretScanningAlertResolved as SecretScanningAlertResolved,
        WebhookSecretScanningAlertUnassigned as SecretScanningAlertUnassigned,
        WebhookSecretScanningAlertValidated as SecretScanningAlertValidated,
        WebhookSecretScanningScanCompleted as SecretScanningScanCompleted,
        WebhookSecurityAdvisoryPublished as SecurityAdvisoryPublished,
        WebhookSecurityAdvisoryUpdated as SecurityAdvisoryUpdated,
        WebhookSecurityAdvisoryWithdrawn as SecurityAdvisoryWithdrawn,
        WebhookSponsorshipCancelled as SponsorshipCancelled,
        WebhookSponsorshipCreated as SponsorshipCreated,
        WebhookSponsorshipEdited as SponsorshipEdited,
        WebhookSponsorshipPendingCancellation as SponsorshipPendingCancellation,
        WebhookSponsorshipPendingTierChange as SponsorshipPendingTierChange,
        WebhookSponsorshipTierChanged as SponsorshipTierChanged,
        WebhookStarCreated as StarCreated,
        WebhookStarDeleted as StarDeleted,
        WebhookSubIssuesParentIssueAdded as SubIssuesParentIssueAdded,
        WebhookSubIssuesParentIssueRemoved as SubIssuesParentIssueRemoved,
        WebhookSubIssuesSubIssueAdded as SubIssuesSubIssueAdded,
        WebhookSubIssuesSubIssueRemoved as SubIssuesSubIssueRemoved,
        WebhookTeamAddedToRepository as TeamAddedToRepository,
        WebhookTeamCreated as TeamCreated,
        WebhookTeamDeleted as TeamDeleted,
        WebhookTeamEdited as TeamEdited,
        WebhookTeamRemovedFromRepository as TeamRemovedFromRepository,
        WebhookWatchStarted as WatchStarted,
        WebhookWorkflowJobCompleted as WorkflowJobCompleted,
        WebhookWorkflowJobInProgress as WorkflowJobInProgress,
        WebhookWorkflowJobQueued as WorkflowJobQueued,
        WebhookWorkflowJobWaiting as WorkflowJobWaiting,
        WebhookWorkflowRunCompleted as WorkflowRunCompleted,
        WebhookWorkflowRunInProgress as WorkflowRunInProgress,
        WebhookWorkflowRunRequested as WorkflowRunRequested,
    )
else:
    __lazy_vars__ = {
        "__monalisten_sentinel__": ("__monalisten_sentinel__",),
        "BranchProtectionConfigurationEvent": ("BranchProtectionConfiguration",),
        "BranchProtectionRuleEvent": ("BranchProtectionRule",),
        "CheckRunEvent": ("CheckRun",),
        "CheckSuiteEvent": ("CheckSuite",),
        "CodeScanningAlertEvent": ("CodeScanningAlert",),
        "CommitCommentEvent": ("CommitComment",),
        "CreateEvent": ("Create",),
        "CustomPropertyEvent": ("CustomProperty",),
        "CustomPropertyValuesEvent": ("CustomPropertyValues",),
        "DeleteEvent": ("Delete",),
        "DependabotAlertEvent": ("DependabotAlert",),
        "DeployKeyEvent": ("DeployKey",),
        "DeploymentEvent": ("Deployment",),
        "DeploymentProtectionRuleEvent": ("DeploymentProtectionRule",),
        "DeploymentReviewEvent": ("DeploymentReview",),
        "DeploymentStatusEvent": ("DeploymentStatus",),
        "DiscussionCommentEvent": ("DiscussionComment",),
        "DiscussionEvent": ("Discussion",),
        "ForkEvent": ("Fork",),
        "GithubAppAuthorizationEvent": ("GithubAppAuthorization",),
        "GollumEvent": ("Gollum",),
        "InstallationEvent": ("Installation",),
        "InstallationRepositoriesEvent": ("InstallationRepositories",),
        "InstallationTargetEvent": ("InstallationTarget",),
        "IssueCommentEvent": ("IssueComment",),
        "IssueDependenciesEvent": ("IssueDependencies",),
        "IssuesEvent": ("Issues",),
        "LabelEvent": ("Label",),
        "MarketplacePurchaseEvent": ("MarketplacePurchase",),
        "MemberEvent": ("Member",),
        "MembershipEvent": ("Membership",),
        "MergeGroupEvent": ("MergeGroup",),
        "MetaEvent": ("Meta",),
        "MilestoneEvent": ("Milestone",),
        "OrgBlockEvent": ("OrgBlock",),
        "OrganizationEvent": ("Organization",),
        "PackageEvent": ("Package",),
        "PageBuildEvent": ("PageBuild",),
        "PersonalAccessTokenRequestEvent": ("PersonalAccessTokenRequest",),
        "PingEvent": ("Ping",),
        "ProjectCardEvent": ("ProjectCard",),
        "ProjectColumnEvent": ("ProjectColumn",),
        "ProjectEvent": ("Project",),
        "ProjectsV2Event": ("ProjectsV2",),
        "ProjectsV2ItemEvent": ("ProjectsV2Item",),
        "ProjectsV2StatusUpdateEvent": ("ProjectsV2StatusUpdate",),
        "PublicEvent": ("Public",),
        "PullRequestEvent": ("PullRequest",),
        "PullRequestReviewCommentEvent": ("PullRequestReviewComment",),
        "PullRequestReviewEvent": ("PullRequestReview",),
        "PullRequestReviewThreadEvent": ("PullRequestReviewThread",),
        "PushEvent": ("Push",),
        "RegistryPackageEvent": ("RegistryPackage",),
        "ReleaseEvent": ("Release",),
        "RepositoryAdvisoryEvent": ("RepositoryAdvisory",),
        "RepositoryDispatchEvent": ("RepositoryDispatch",),
        "RepositoryEvent": ("Repository",),
        "RepositoryImportEvent": ("RepositoryImport",),
        "RepositoryRulesetEvent": ("RepositoryRuleset",),
        "RepositoryVulnerabilityAlertEvent": ("RepositoryVulnerabilityAlert",),
        "SecretScanningAlertEvent": ("SecretScanningAlert",),
        "SecretScanningAlertLocationEvent": ("SecretScanningAlertLocation",),
        "SecretScanningScanEvent": ("SecretScanningScan",),
        "SecurityAdvisoryEvent": ("SecurityAdvisory",),
        "SecurityAndAnalysisEvent": ("SecurityAndAnalysis",),
        "SponsorshipEvent": ("Sponsorship",),
        "StarEvent": ("Star",),
        "StatusEvent": ("Status",),
        "SubIssuesEvent": ("SubIssues",),
        "TeamAddEvent": ("TeamAdd",),
        "TeamEvent": ("Team",),
        "WatchEvent": ("Watch",),
        "WebhookBranchProtectionConfigurationDisabled": (
            "BranchProtectionConfigurationDisabled",
        ),
        "WebhookBranchProtectionConfigurationEnabled": (
            "BranchProtectionConfigurationEnabled",
        ),
        "WebhookBranchProtectionRuleCreated": ("BranchProtectionRuleCreated",),
        "WebhookBranchProtectionRuleDeleted": ("BranchProtectionRuleDeleted",),
        "WebhookBranchProtectionRuleEdited": ("BranchProtectionRuleEdited",),
        "WebhookCheckRunCompleted": ("CheckRunCompleted",),
        "WebhookCheckRunCreated": ("CheckRunCreated",),
        "WebhookCheckRunRequestedAction": ("CheckRunRequestedAction",),
        "WebhookCheckRunRerequested": ("CheckRunRerequested",),
        "WebhookCheckSuiteCompleted": ("CheckSuiteCompleted",),
        "WebhookCheckSuiteRequested": ("CheckSuiteRequested",),
        "WebhookCheckSuiteRerequested": ("CheckSuiteRerequested",),
        "WebhookCodeScanningAlertAppearedInBranch": (
            "CodeScanningAlertAppearedInBranch",
        ),
        "WebhookCodeScanningAlertClosedByUser": ("CodeScanningAlertClosedByUser",),
        "WebhookCodeScanningAlertCreated": ("CodeScanningAlertCreated",),
        "WebhookCodeScanningAlertFixed": ("CodeScanningAlertFixed",),
        "WebhookCodeScanningAlertReopened": ("CodeScanningAlertReopened",),
        "WebhookCodeScanningAlertReopenedByUser": ("CodeScanningAlertReopenedByUser",),
        "WebhookCodeScanningAlertUpdatedAssignment": (
            "CodeScanningAlertUpdatedAssignment",
        ),
        "WebhookCommitCommentCreated": ("CommitCommentCreated",),
        "WebhookCustomPropertyCreated": ("CustomPropertyCreated",),
        "WebhookCustomPropertyDeleted": ("CustomPropertyDeleted",),
        "WebhookCustomPropertyPromotedToEnterprise": (
            "CustomPropertyPromoteToEnterprise",
        ),
        "WebhookCustomPropertyUpdated": ("CustomPropertyUpdated",),
        "WebhookCustomPropertyValuesUpdated": ("CustomPropertyValuesUpdated",),
        "WebhookDependabotAlertAssigneesChanged": ("DependabotAlertAssigneesChanged",),
        "WebhookDependabotAlertAutoDismissed": ("DependabotAlertAutoDismissed",),
        "WebhookDependabotAlertAutoReopened": ("DependabotAlertAutoReopened",),
        "WebhookDependabotAlertCreated": ("DependabotAlertCreated",),
        "WebhookDependabotAlertDismissed": ("DependabotAlertDismissed",),
        "WebhookDependabotAlertFixed": ("DependabotAlertFixed",),
        "WebhookDependabotAlertReintroduced": ("DependabotAlertReintroduced",),
        "WebhookDependabotAlertReopened": ("DependabotAlertReopened",),
        "WebhookDeployKeyCreated": ("DeployKeyCreated",),
        "WebhookDeployKeyDeleted": ("DeployKeyDeleted",),
        "WebhookDeploymentCreated": ("DeploymentCreated",),
        "WebhookDeploymentProtectionRuleRequested": (
            "DeploymentProtectionRuleRequested",
        ),
        "WebhookDeploymentReviewApproved": ("DeploymentReviewApproved",),
        "WebhookDeploymentReviewRejected": ("DeploymentReviewRejected",),
        "WebhookDeploymentReviewRequested": ("DeploymentReviewRequested",),
        "WebhookDeploymentStatusCreated": ("DeploymentStatusCreated",),
        "WebhookDiscussionAnswered": ("DiscussionAnswered",),
        "WebhookDiscussionCategoryChanged": ("DiscussionCategoryChanged",),
        "WebhookDiscussionClosed": ("DiscussionClosed",),
        "WebhookDiscussionCommentCreated": ("DiscussionCommentCreated",),
        "WebhookDiscussionCommentDeleted": ("DiscussionCommentDeleted",),
        "WebhookDiscussionCommentEdited": ("DiscussionCommentEdited",),
        "WebhookDiscussionCreated": ("DiscussionCreated",),
        "WebhookDiscussionDeleted": ("DiscussionDeleted",),
        "WebhookDiscussionEdited": ("DiscussionEdited",),
        "WebhookDiscussionLabeled": ("DiscussionLabeled",),
        "WebhookDiscussionLocked": ("DiscussionLocked",),
        "WebhookDiscussionPinned": ("DiscussionPinned",),
        "WebhookDiscussionReopened": ("DiscussionReopened",),
        "WebhookDiscussionTransferred": ("DiscussionTransferred",),
        "WebhookDiscussionUnanswered": ("DiscussionUnanswered",),
        "WebhookDiscussionUnlabeled": ("DiscussionUnlabeled",),
        "WebhookDiscussionUnlocked": ("DiscussionUnlocked",),
        "WebhookDiscussionUnpinned": ("DiscussionUnpinned",),
        "WebhookEvent": ("Any",),
        "WebhookGithubAppAuthorizationRevoked": ("GithubAppAuthorizationRevoked",),
        "WebhookInstallationCreated": ("InstallationCreated",),
        "WebhookInstallationDeleted": ("InstallationDeleted",),
        "WebhookInstallationNewPermissionsAccepted": (
            "InstallationNewPermissionsAccepted",
        ),
        "WebhookInstallationRepositoriesAdded": ("InstallationRepositoriesAdded",),
        "WebhookInstallationRepositoriesRemoved": ("InstallationRepositoriesRemoved",),
        "WebhookInstallationSuspend": ("InstallationSuspend",),
        "WebhookInstallationTargetRenamed": ("InstallationTargetRenamed",),
        "WebhookInstallationUnsuspend": ("InstallationUnsuspend",),
        "WebhookIssueCommentCreated": ("IssueCommentCreated",),
        "WebhookIssueCommentDeleted": ("IssueCommentDeleted",),
        "WebhookIssueCommentEdited": ("IssueCommentEdited",),
        "WebhookIssueCommentPinned": ("IssueCommentPinned",),
        "WebhookIssueCommentUnpinned": ("IssueCommentUnpinned",),
        "WebhookIssueDependenciesBlockedByAdded": ("IssueDependenciesBlockedByAdded",),
        "WebhookIssueDependenciesBlockedByRemoved": (
            "IssueDependenciesBlockedByRemoved",
        ),
        "WebhookIssueDependenciesBlockingAdded": ("IssueDependenciesBlockingAdded",),
        "WebhookIssueDependenciesBlockingRemoved": (
            "IssueDependenciesBlockingRemoved",
        ),
        "WebhookIssuesAssigned": ("IssuesAssigned",),
        "WebhookIssuesClosed": ("IssuesClosed",),
        "WebhookIssuesDeleted": ("IssuesDeleted",),
        "WebhookIssuesDemilestoned": ("IssuesDemilestoned",),
        "WebhookIssuesEdited": ("IssuesEdited",),
        "WebhookIssuesLabeled": ("IssuesLabeled",),
        "WebhookIssuesLocked": ("IssuesLocked",),
        "WebhookIssuesMilestoned": ("IssuesMilestoned",),
        "WebhookIssuesOpened": ("IssuesOpened",),
        "WebhookIssuesPinned": ("IssuesPinned",),
        "WebhookIssuesReopened": ("IssuesReopened",),
        "WebhookIssuesTransferred": ("IssuesTransferred",),
        "WebhookIssuesTyped": ("IssuesTyped",),
        "WebhookIssuesUnassigned": ("IssuesUnassigned",),
        "WebhookIssuesUnlabeled": ("IssuesUnlabeled",),
        "WebhookIssuesUnlocked": ("IssuesUnlocked",),
        "WebhookIssuesUnpinned": ("IssuesUnpinned",),
        "WebhookIssuesUntyped": ("IssuesUntyped",),
        "WebhookLabelCreated": ("LabelCreated",),
        "WebhookLabelDeleted": ("LabelDeleted",),
        "WebhookLabelEdited": ("LabelEdited",),
        "WebhookMarketplacePurchaseCancelled": ("MarketplacePurchaseCancelled",),
        "WebhookMarketplacePurchaseChanged": ("MarketplacePurchaseChanged",),
        "WebhookMarketplacePurchasePendingChange": (
            "MarketplacePurchasePendingChange",
        ),
        "WebhookMarketplacePurchasePendingChangeCancelled": (
            "MarketplacePurchasePendingChangeCancelled",
        ),
        "WebhookMarketplacePurchasePurchased": ("MarketplacePurchasePurchased",),
        "WebhookMemberAdded": ("MemberAdded",),
        "WebhookMemberEdited": ("MemberEdited",),
        "WebhookMemberRemoved": ("MemberRemoved",),
        "WebhookMembershipAdded": ("MembershipAdded",),
        "WebhookMembershipRemoved": ("MembershipRemoved",),
        "WebhookMergeGroupChecksRequested": ("MergeGroupChecksRequested",),
        "WebhookMergeGroupDestroyed": ("MergeGroupDestroyed",),
        "WebhookMetaDeleted": ("MetaDeleted",),
        "WebhookMilestoneClosed": ("MilestoneClosed",),
        "WebhookMilestoneCreated": ("MilestoneCreated",),
        "WebhookMilestoneDeleted": ("MilestoneDeleted",),
        "WebhookMilestoneEdited": ("MilestoneEdited",),
        "WebhookMilestoneOpened": ("MilestoneOpened",),
        "WebhookOrgBlockBlocked": ("OrgBlockBlocked",),
        "WebhookOrgBlockUnblocked": ("OrgBlockUnblocked",),
        "WebhookOrganizationDeleted": ("OrganizationDeleted",),
        "WebhookOrganizationMemberAdded": ("OrganizationMemberAdded",),
        "WebhookOrganizationMemberInvited": ("OrganizationMemberInvited",),
        "WebhookOrganizationMemberRemoved": ("OrganizationMemberRemoved",),
        "WebhookOrganizationRenamed": ("OrganizationRenamed",),
        "WebhookPackagePublished": ("PackagePublished",),
        "WebhookPackageUpdated": ("PackageUpdated",),
        "WebhookPersonalAccessTokenRequestApproved": (
            "PersonalAccessTokenRequestApproved",
        ),
        "WebhookPersonalAccessTokenRequestCancelled": (
            "PersonalAccessTokenRequestCancelled",
        ),
        "WebhookPersonalAccessTokenRequestCreated": (
            "PersonalAccessTokenRequestCreated",
        ),
        "WebhookPersonalAccessTokenRequestDenied": (
            "PersonalAccessTokenRequestDenied",
        ),
        "WebhookProjectCardConverted": ("ProjectCardConverted",),
        "WebhookProjectCardCreated": ("ProjectCardCreated",),
        "WebhookProjectCardDeleted": ("ProjectCardDeleted",),
        "WebhookProjectCardEdited": ("ProjectCardEdited",),
        "WebhookProjectCardMoved": ("ProjectCardMoved",),
        "WebhookProjectClosed": ("ProjectClosed",),
        "WebhookProjectColumnCreated": ("ProjectColumnCreated",),
        "WebhookProjectColumnDeleted": ("ProjectColumnDeleted",),
        "WebhookProjectColumnEdited": ("ProjectColumnEdited",),
        "WebhookProjectColumnMoved": ("ProjectColumnMoved",),
        "WebhookProjectCreated": ("ProjectCreated",),
        "WebhookProjectDeleted": ("ProjectDeleted",),
        "WebhookProjectEdited": ("ProjectEdited",),
        "WebhookProjectReopened": ("ProjectReopened",),
        "WebhookProjectsV2ItemArchived": ("ProjectsV2ItemArchived",),
        "WebhookProjectsV2ItemConverted": ("ProjectsV2ItemConverted",),
        "WebhookProjectsV2ItemCreated": ("ProjectsV2ItemCreated",),
        "WebhookProjectsV2ItemDeleted": ("ProjectsV2ItemDeleted",),
        "WebhookProjectsV2ItemEdited": ("ProjectsV2ItemEdited",),
        "WebhookProjectsV2ItemReordered": ("ProjectsV2ItemReordered",),
        "WebhookProjectsV2ItemRestored": ("ProjectsV2ItemRestored",),
        "WebhookProjectsV2ProjectClosed": ("ProjectsV2ProjectClosed",),
        "WebhookProjectsV2ProjectCreated": ("ProjectsV2ProjectCreated",),
        "WebhookProjectsV2ProjectDeleted": ("ProjectsV2ProjectDeleted",),
        "WebhookProjectsV2ProjectEdited": ("ProjectsV2ProjectEdited",),
        "WebhookProjectsV2ProjectReopened": ("ProjectsV2ProjectReopened",),
        "WebhookProjectsV2StatusUpdateCreated": ("ProjectsV2StatusUpdateCreated",),
        "WebhookProjectsV2StatusUpdateDeleted": ("ProjectsV2StatusUpdateDeleted",),
        "WebhookProjectsV2StatusUpdateEdited": ("ProjectsV2StatusUpdateEdited",),
        "WebhookPullRequestAssigned": ("PullRequestAssigned",),
        "WebhookPullRequestAutoMergeDisabled": ("PullRequestAutoMergeDisabled",),
        "WebhookPullRequestAutoMergeEnabled": ("PullRequestAutoMergeEnabled",),
        "WebhookPullRequestClosed": ("PullRequestClosed",),
        "WebhookPullRequestConvertedToDraft": ("PullRequestConvertedToDraft",),
        "WebhookPullRequestDemilestoned": ("PullRequestDemilestoned",),
        "WebhookPullRequestDequeued": ("PullRequestDequeued",),
        "WebhookPullRequestEdited": ("PullRequestEdited",),
        "WebhookPullRequestEnqueued": ("PullRequestEnqueued",),
        "WebhookPullRequestLabeled": ("PullRequestLabeled",),
        "WebhookPullRequestLocked": ("PullRequestLocked",),
        "WebhookPullRequestMilestoned": ("PullRequestMilestoned",),
        "WebhookPullRequestOpened": ("PullRequestOpened",),
        "WebhookPullRequestReadyForReview": ("PullRequestReadyForReview",),
        "WebhookPullRequestReopened": ("PullRequestReopened",),
        "WebhookPullRequestReviewCommentCreated": ("PullRequestReviewCommentCreated",),
        "WebhookPullRequestReviewCommentDeleted": ("PullRequestReviewCommentDeleted",),
        "WebhookPullRequestReviewCommentEdited": ("PullRequestReviewCommentEdited",),
        "WebhookPullRequestReviewDismissed": ("PullRequestReviewDismissed",),
        "WebhookPullRequestReviewEdited": ("PullRequestReviewEdited",),
        "WebhookPullRequestReviewSubmitted": ("PullRequestReviewSubmitted",),
        "WebhookPullRequestReviewThreadResolved": ("PullRequestReviewThreadResolved",),
        "WebhookPullRequestReviewThreadUnresolved": (
            "PullRequestReviewThreadUnresolved",
        ),
        "WebhookPullRequestSynchronize": ("PullRequestSynchronize",),
        "WebhookPullRequestUnassigned": ("PullRequestUnassigned",),
        "WebhookPullRequestUnlabeled": ("PullRequestUnlabeled",),
        "WebhookPullRequestUnlocked": ("PullRequestUnlocked",),
        "WebhookRegistryPackagePublished": ("RegistryPackagePublished",),
        "WebhookRegistryPackageUpdated": ("RegistryPackageUpdated",),
        "WebhookReleaseCreated": ("ReleaseCreated",),
        "WebhookReleaseDeleted": ("ReleaseDeleted",),
        "WebhookReleaseEdited": ("ReleaseEdited",),
        "WebhookReleasePrereleased": ("ReleasePrereleased",),
        "WebhookReleasePublished": ("ReleasePublished",),
        "WebhookReleaseReleased": ("ReleaseReleased",),
        "WebhookReleaseUnpublished": ("ReleaseUnpublished",),
        "WebhookRepositoryAdvisoryPublished": ("RepositoryAdvisoryPublished",),
        "WebhookRepositoryAdvisoryReported": ("RepositoryAdvisoryReported",),
        "WebhookRepositoryArchived": ("RepositoryArchived",),
        "WebhookRepositoryCreated": ("RepositoryCreated",),
        "WebhookRepositoryDeleted": ("RepositoryDeleted",),
        "WebhookRepositoryDispatchSample": ("RepositoryDispatchSample",),
        "WebhookRepositoryEdited": ("RepositoryEdited",),
        "WebhookRepositoryPrivatized": ("RepositoryPrivatized",),
        "WebhookRepositoryPublicized": ("RepositoryPublicized",),
        "WebhookRepositoryRenamed": ("RepositoryRenamed",),
        "WebhookRepositoryRulesetCreated": ("RepositoryRulesetCreated",),
        "WebhookRepositoryRulesetDeleted": ("RepositoryRulesetDeleted",),
        "WebhookRepositoryRulesetEdited": ("RepositoryRulesetEdited",),
        "WebhookRepositoryTransferred": ("RepositoryTransferred",),
        "WebhookRepositoryUnarchived": ("RepositoryUnarchived",),
        "WebhookRepositoryVulnerabilityAlertCreate": (
            "RepositoryVulnerabilityAlertCreate",
        ),
        "WebhookRepositoryVulnerabilityAlertDismiss": (
            "RepositoryVulnerabilityAlertDismiss",
        ),
        "WebhookRepositoryVulnerabilityAlertReopen": (
            "RepositoryVulnerabilityAlertReopen",
        ),
        "WebhookRepositoryVulnerabilityAlertResolve": (
            "RepositoryVulnerabilityAlertResolve",
        ),
        "WebhookSecretScanningAlertAssigned": ("SecretScanningAlertAssigned",),
        "WebhookSecretScanningAlertCreated": ("SecretScanningAlertCreated",),
        "WebhookSecretScanningAlertLocationCreated": (
            "SecretScanningAlertLocationCreated",
        ),
        "WebhookSecretScanningAlertPubliclyLeaked": (
            "SecretScanningAlertPubliclyLeaked",
        ),
        "WebhookSecretScanningAlertReopened": ("SecretScanningAlertReopened",),
        "WebhookSecretScanningAlertResolved": ("SecretScanningAlertResolved",),
        "WebhookSecretScanningAlertUnassigned": ("SecretScanningAlertUnassigned",),
        "WebhookSecretScanningAlertValidated": ("SecretScanningAlertValidated",),
        "WebhookSecretScanningScanCompleted": ("SecretScanningScanCompleted",),
        "WebhookSecurityAdvisoryPublished": ("SecurityAdvisoryPublished",),
        "WebhookSecurityAdvisoryUpdated": ("SecurityAdvisoryUpdated",),
        "WebhookSecurityAdvisoryWithdrawn": ("SecurityAdvisoryWithdrawn",),
        "WebhookSponsorshipCancelled": ("SponsorshipCancelled",),
        "WebhookSponsorshipCreated": ("SponsorshipCreated",),
        "WebhookSponsorshipEdited": ("SponsorshipEdited",),
        "WebhookSponsorshipPendingCancellation": ("SponsorshipPendingCancellation",),
        "WebhookSponsorshipPendingTierChange": ("SponsorshipPendingTierChange",),
        "WebhookSponsorshipTierChanged": ("SponsorshipTierChanged",),
        "WebhookStarCreated": ("StarCreated",),
        "WebhookStarDeleted": ("StarDeleted",),
        "WebhookSubIssuesParentIssueAdded": ("SubIssuesParentIssueAdded",),
        "WebhookSubIssuesParentIssueRemoved": ("SubIssuesParentIssueRemoved",),
        "WebhookSubIssuesSubIssueAdded": ("SubIssuesSubIssueAdded",),
        "WebhookSubIssuesSubIssueRemoved": ("SubIssuesSubIssueRemoved",),
        "WebhookTeamAddedToRepository": ("TeamAddedToRepository",),
        "WebhookTeamCreated": ("TeamCreated",),
        "WebhookTeamDeleted": ("TeamDeleted",),
        "WebhookTeamEdited": ("TeamEdited",),
        "WebhookTeamRemovedFromRepository": ("TeamRemovedFromRepository",),
        "WebhookWatchStarted": ("WatchStarted",),
        "WebhookWorkflowJobCompleted": ("WorkflowJobCompleted",),
        "WebhookWorkflowJobInProgress": ("WorkflowJobInProgress",),
        "WebhookWorkflowJobQueued": ("WorkflowJobQueued",),
        "WebhookWorkflowJobWaiting": ("WorkflowJobWaiting",),
        "WebhookWorkflowRunCompleted": ("WorkflowRunCompleted",),
        "WebhookWorkflowRunInProgress": ("WorkflowRunInProgress",),
        "WebhookWorkflowRunRequested": ("WorkflowRunRequested",),
        "WorkflowDispatchEvent": ("WorkflowDispatch",),
        "WorkflowJobEvent": ("WorkflowJob",),
        "WorkflowRunEvent": ("WorkflowRun",),
    }

__all__: tuple[str, ...] = (
    "Any",
    "BranchProtectionConfiguration",
    "BranchProtectionConfigurationDisabled",
    "BranchProtectionConfigurationEnabled",
    "BranchProtectionRule",
    "BranchProtectionRuleCreated",
    "BranchProtectionRuleDeleted",
    "BranchProtectionRuleEdited",
    "CheckRun",
    "CheckRunCompleted",
    "CheckRunCreated",
    "CheckRunRequestedAction",
    "CheckRunRerequested",
    "CheckSuite",
    "CheckSuiteCompleted",
    "CheckSuiteRequested",
    "CheckSuiteRerequested",
    "CodeScanningAlert",
    "CodeScanningAlertAppearedInBranch",
    "CodeScanningAlertClosedByUser",
    "CodeScanningAlertCreated",
    "CodeScanningAlertFixed",
    "CodeScanningAlertReopened",
    "CodeScanningAlertReopenedByUser",
    "CodeScanningAlertUpdatedAssignment",
    "CommitComment",
    "CommitCommentCreated",
    "Create",
    "CustomProperty",
    "CustomPropertyCreated",
    "CustomPropertyDeleted",
    "CustomPropertyPromoteToEnterprise",
    "CustomPropertyUpdated",
    "CustomPropertyValues",
    "CustomPropertyValuesUpdated",
    "Delete",
    "DependabotAlert",
    "DependabotAlertAssigneesChanged",
    "DependabotAlertAutoDismissed",
    "DependabotAlertAutoReopened",
    "DependabotAlertCreated",
    "DependabotAlertDismissed",
    "DependabotAlertFixed",
    "DependabotAlertReintroduced",
    "DependabotAlertReopened",
    "DeployKey",
    "DeployKeyCreated",
    "DeployKeyDeleted",
    "Deployment",
    "DeploymentCreated",
    "DeploymentProtectionRule",
    "DeploymentProtectionRuleRequested",
    "DeploymentReview",
    "DeploymentReviewApproved",
    "DeploymentReviewRejected",
    "DeploymentReviewRequested",
    "DeploymentStatus",
    "DeploymentStatusCreated",
    "Discussion",
    "DiscussionAnswered",
    "DiscussionCategoryChanged",
    "DiscussionClosed",
    "DiscussionComment",
    "DiscussionCommentCreated",
    "DiscussionCommentDeleted",
    "DiscussionCommentEdited",
    "DiscussionCreated",
    "DiscussionDeleted",
    "DiscussionEdited",
    "DiscussionLabeled",
    "DiscussionLocked",
    "DiscussionPinned",
    "DiscussionReopened",
    "DiscussionTransferred",
    "DiscussionUnanswered",
    "DiscussionUnlabeled",
    "DiscussionUnlocked",
    "DiscussionUnpinned",
    "Fork",
    "GithubAppAuthorization",
    "GithubAppAuthorizationRevoked",
    "Gollum",
    "Installation",
    "InstallationCreated",
    "InstallationDeleted",
    "InstallationNewPermissionsAccepted",
    "InstallationRepositories",
    "InstallationRepositoriesAdded",
    "InstallationRepositoriesRemoved",
    "InstallationSuspend",
    "InstallationTarget",
    "InstallationTargetRenamed",
    "InstallationUnsuspend",
    "IssueComment",
    "IssueCommentCreated",
    "IssueCommentDeleted",
    "IssueCommentEdited",
    "IssueCommentPinned",
    "IssueCommentUnpinned",
    "IssueDependencies",
    "IssueDependenciesBlockedByAdded",
    "IssueDependenciesBlockedByRemoved",
    "IssueDependenciesBlockingAdded",
    "IssueDependenciesBlockingRemoved",
    "Issues",
    "IssuesAssigned",
    "IssuesClosed",
    "IssuesDeleted",
    "IssuesDemilestoned",
    "IssuesEdited",
    "IssuesLabeled",
    "IssuesLocked",
    "IssuesMilestoned",
    "IssuesOpened",
    "IssuesPinned",
    "IssuesReopened",
    "IssuesTransferred",
    "IssuesTyped",
    "IssuesUnassigned",
    "IssuesUnlabeled",
    "IssuesUnlocked",
    "IssuesUnpinned",
    "IssuesUntyped",
    "Label",
    "LabelCreated",
    "LabelDeleted",
    "LabelEdited",
    "MarketplacePurchase",
    "MarketplacePurchaseCancelled",
    "MarketplacePurchaseChanged",
    "MarketplacePurchasePendingChange",
    "MarketplacePurchasePendingChangeCancelled",
    "MarketplacePurchasePurchased",
    "Member",
    "MemberAdded",
    "MemberEdited",
    "MemberRemoved",
    "Membership",
    "MembershipAdded",
    "MembershipRemoved",
    "MergeGroup",
    "MergeGroupChecksRequested",
    "MergeGroupDestroyed",
    "Meta",
    "MetaDeleted",
    "Milestone",
    "MilestoneClosed",
    "MilestoneCreated",
    "MilestoneDeleted",
    "MilestoneEdited",
    "MilestoneOpened",
    "OrgBlock",
    "OrgBlockBlocked",
    "OrgBlockUnblocked",
    "Organization",
    "OrganizationDeleted",
    "OrganizationMemberAdded",
    "OrganizationMemberInvited",
    "OrganizationMemberRemoved",
    "OrganizationRenamed",
    "Package",
    "PackagePublished",
    "PackageUpdated",
    "PageBuild",
    "PersonalAccessTokenRequest",
    "PersonalAccessTokenRequestApproved",
    "PersonalAccessTokenRequestCancelled",
    "PersonalAccessTokenRequestCreated",
    "PersonalAccessTokenRequestDenied",
    "Ping",
    "Project",
    "ProjectCard",
    "ProjectCardConverted",
    "ProjectCardCreated",
    "ProjectCardDeleted",
    "ProjectCardEdited",
    "ProjectCardMoved",
    "ProjectClosed",
    "ProjectColumn",
    "ProjectColumnCreated",
    "ProjectColumnDeleted",
    "ProjectColumnEdited",
    "ProjectColumnMoved",
    "ProjectCreated",
    "ProjectDeleted",
    "ProjectEdited",
    "ProjectReopened",
    "ProjectsV2",
    "ProjectsV2Item",
    "ProjectsV2ItemArchived",
    "ProjectsV2ItemConverted",
    "ProjectsV2ItemCreated",
    "ProjectsV2ItemDeleted",
    "ProjectsV2ItemEdited",
    "ProjectsV2ItemReordered",
    "ProjectsV2ItemRestored",
    "ProjectsV2ProjectClosed",
    "ProjectsV2ProjectCreated",
    "ProjectsV2ProjectDeleted",
    "ProjectsV2ProjectEdited",
    "ProjectsV2ProjectReopened",
    "ProjectsV2StatusUpdate",
    "ProjectsV2StatusUpdateCreated",
    "ProjectsV2StatusUpdateDeleted",
    "ProjectsV2StatusUpdateEdited",
    "Public",
    "PullRequest",
    "PullRequestAssigned",
    "PullRequestAutoMergeDisabled",
    "PullRequestAutoMergeEnabled",
    "PullRequestClosed",
    "PullRequestConvertedToDraft",
    "PullRequestDemilestoned",
    "PullRequestDequeued",
    "PullRequestEdited",
    "PullRequestEnqueued",
    "PullRequestLabeled",
    "PullRequestLocked",
    "PullRequestMilestoned",
    "PullRequestOpened",
    "PullRequestReadyForReview",
    "PullRequestReopened",
    "PullRequestReview",
    "PullRequestReviewComment",
    "PullRequestReviewCommentCreated",
    "PullRequestReviewCommentDeleted",
    "PullRequestReviewCommentEdited",
    "PullRequestReviewDismissed",
    "PullRequestReviewEdited",
    "PullRequestReviewSubmitted",
    "PullRequestReviewThread",
    "PullRequestReviewThreadResolved",
    "PullRequestReviewThreadUnresolved",
    "PullRequestSynchronize",
    "PullRequestUnassigned",
    "PullRequestUnlabeled",
    "PullRequestUnlocked",
    "Push",
    "RegistryPackage",
    "RegistryPackagePublished",
    "RegistryPackageUpdated",
    "Release",
    "ReleaseCreated",
    "ReleaseDeleted",
    "ReleaseEdited",
    "ReleasePrereleased",
    "ReleasePublished",
    "ReleaseReleased",
    "ReleaseUnpublished",
    "Repository",
    "RepositoryAdvisory",
    "RepositoryAdvisoryPublished",
    "RepositoryAdvisoryReported",
    "RepositoryArchived",
    "RepositoryCreated",
    "RepositoryDeleted",
    "RepositoryDispatch",
    "RepositoryDispatchSample",
    "RepositoryEdited",
    "RepositoryImport",
    "RepositoryPrivatized",
    "RepositoryPublicized",
    "RepositoryRenamed",
    "RepositoryRuleset",
    "RepositoryRulesetCreated",
    "RepositoryRulesetDeleted",
    "RepositoryRulesetEdited",
    "RepositoryTransferred",
    "RepositoryUnarchived",
    "RepositoryVulnerabilityAlert",
    "RepositoryVulnerabilityAlertCreate",
    "RepositoryVulnerabilityAlertDismiss",
    "RepositoryVulnerabilityAlertReopen",
    "RepositoryVulnerabilityAlertResolve",
    "SecretScanningAlert",
    "SecretScanningAlertAssigned",
    "SecretScanningAlertCreated",
    "SecretScanningAlertLocation",
    "SecretScanningAlertLocationCreated",
    "SecretScanningAlertPubliclyLeaked",
    "SecretScanningAlertReopened",
    "SecretScanningAlertResolved",
    "SecretScanningAlertUnassigned",
    "SecretScanningAlertValidated",
    "SecretScanningScan",
    "SecretScanningScanCompleted",
    "SecurityAdvisory",
    "SecurityAdvisoryPublished",
    "SecurityAdvisoryUpdated",
    "SecurityAdvisoryWithdrawn",
    "SecurityAndAnalysis",
    "Sponsorship",
    "SponsorshipCancelled",
    "SponsorshipCreated",
    "SponsorshipEdited",
    "SponsorshipPendingCancellation",
    "SponsorshipPendingTierChange",
    "SponsorshipTierChanged",
    "Star",
    "StarCreated",
    "StarDeleted",
    "Status",
    "SubIssues",
    "SubIssuesParentIssueAdded",
    "SubIssuesParentIssueRemoved",
    "SubIssuesSubIssueAdded",
    "SubIssuesSubIssueRemoved",
    "Team",
    "TeamAdd",
    "TeamAddedToRepository",
    "TeamCreated",
    "TeamDeleted",
    "TeamEdited",
    "TeamRemovedFromRepository",
    "Watch",
    "WatchStarted",
    "WorkflowDispatch",
    "WorkflowJob",
    "WorkflowJobCompleted",
    "WorkflowJobInProgress",
    "WorkflowJobQueued",
    "WorkflowJobWaiting",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunInProgress",
    "WorkflowRunRequested",
)
